@@ -11,11 +11,14 @@ FIFO as a transport to stream integers between the two languages.
 import asyncio
 from collections import deque
 import json
+import os
 from typing import Optional
 
 import aiohttp.web
 
 from swh.core.api.asynchronous import RPCServerApp
+from swh.core.config import read as config_read
+from swh.graph.backend import Backend
 from swh.model.exceptions import ValidationError
 from swh.model.identifiers import EXTENDED_SWHID_TYPES
 
@@ -30,11 +33,28 @@ except ImportError:
 RANDOM_RETRIES = 5  # TODO make this configurable via rpc-serve configuration
 
 
+class GraphServerApp(RPCServerApp):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.on_startup.append(self._start_gateway)
+        self.on_shutdown.append(self._stop_gateway)
+
+    @staticmethod
+    async def _start_gateway(app):
+        # Equivalent to entering `with app["backend"]:`
+        app["backend"].start_gateway()
+
+    @staticmethod
+    async def _stop_gateway(app):
+        # Equivalent to exiting `with app["backend"]:` with no error
+        app["backend"].stop_gateway()
+
+
 async def index(request):
     return aiohttp.web.Response(
         content_type="text/html",
         body="""<html>
-<head><title>Software Heritage storage server</title></head>
+<head><title>Software Heritage graph server</title></head>
 <body>
 <p>You have reached the <a href="https://www.softwareheritage.org/">
 Software Heritage</a> graph API server.</p>
@@ -154,7 +174,11 @@ class StreamingGraphView(GraphView):
     async def get(self):
         await self.prepare_response()
         async with self.response_streamer() as self.response_stream:
-            await self.stream_response()
+            self._buf = []
+            try:
+                await self.stream_response()
+            finally:
+                await self._flush_buffer()
             return self.response_stream
 
     async def prepare_response(self):
@@ -171,7 +195,13 @@ class StreamingGraphView(GraphView):
 
     async def stream_line(self, line):
         """Write a line in the response stream."""
-        await self.response_stream.write((line + "\n").encode())
+        self._buf.append(line)
+        if len(self._buf) > 100:
+            await self._flush_buffer()
+
+    async def _flush_buffer(self):
+        await self.response_stream.write("\n".join(self._buf).encode() + b"\n")
+        self._buf = []
 
 
 class StatsView(GraphView):
@@ -334,8 +364,12 @@ class CountVisitNodesView(CountView):
     count_type = "visit_nodes"
 
 
-def make_app(backend, **kwargs):
-    app = RPCServerApp(**kwargs)
+def make_app(config=None, backend=None, **kwargs):
+    if (config is None) == (backend is None):
+        raise ValueError("make_app() expects exactly one of 'config' or 'backend'")
+    if backend is None:
+        backend = Backend(graph_path=config["graph"]["path"], config=config["graph"])
+    app = GraphServerApp(**kwargs)
     app.add_routes(
         [
             aiohttp.web.get("/", index),
@@ -357,3 +391,12 @@ def make_app(backend, **kwargs):
 
     app["backend"] = backend
     return app
+
+
+def make_app_from_configfile():
+    """Load configuration and then build application to run
+
+    """
+    config_file = os.environ.get("SWH_CONFIG_FILENAME")
+    config = config_read(config_file)
+    return make_app(config=config)
