@@ -2,6 +2,7 @@ import pytest
 from pytest import raises
 
 from swh.core.api import RemoteException
+from swh.graph.client import GraphArgumentException
 
 
 def test_stats(graph_client):
@@ -75,6 +76,41 @@ def test_visit_nodes(graph_client):
     assert set(actual) == set(expected)
 
 
+def test_visit_nodes_filtered(graph_client):
+    actual = list(
+        graph_client.visit_nodes(
+            "swh:1:rel:0000000000000000000000000000000000000010", return_types="dir",
+        )
+    )
+    expected = [
+        "swh:1:dir:0000000000000000000000000000000000000002",
+        "swh:1:dir:0000000000000000000000000000000000000008",
+        "swh:1:dir:0000000000000000000000000000000000000006",
+    ]
+    assert set(actual) == set(expected)
+
+
+def test_visit_nodes_filtered_star(graph_client):
+    actual = list(
+        graph_client.visit_nodes(
+            "swh:1:rel:0000000000000000000000000000000000000010", return_types="*",
+        )
+    )
+    expected = [
+        "swh:1:rel:0000000000000000000000000000000000000010",
+        "swh:1:rev:0000000000000000000000000000000000000009",
+        "swh:1:rev:0000000000000000000000000000000000000003",
+        "swh:1:dir:0000000000000000000000000000000000000002",
+        "swh:1:cnt:0000000000000000000000000000000000000001",
+        "swh:1:dir:0000000000000000000000000000000000000008",
+        "swh:1:cnt:0000000000000000000000000000000000000007",
+        "swh:1:dir:0000000000000000000000000000000000000006",
+        "swh:1:cnt:0000000000000000000000000000000000000004",
+        "swh:1:cnt:0000000000000000000000000000000000000005",
+    ]
+    assert set(actual) == set(expected)
+
+
 def test_visit_edges(graph_client):
     actual = list(
         graph_client.visit_edges(
@@ -106,7 +142,9 @@ def test_visit_edges(graph_client):
 def test_visit_edges_limited(graph_client):
     actual = list(
         graph_client.visit_edges(
-            "swh:1:rel:0000000000000000000000000000000000000010", max_edges=4
+            "swh:1:rel:0000000000000000000000000000000000000010",
+            max_edges=4,
+            edges="rel:rev,rev:rev,rev:dir",
         )
     )
     expected = [
@@ -116,14 +154,21 @@ def test_visit_edges_limited(graph_client):
         ),
         (
             "swh:1:rev:0000000000000000000000000000000000000009",
-            "swh:1:dir:0000000000000000000000000000000000000008",
+            "swh:1:rev:0000000000000000000000000000000000000003",
         ),
         (
             "swh:1:rev:0000000000000000000000000000000000000009",
+            "swh:1:dir:0000000000000000000000000000000000000008",
+        ),
+        (
             "swh:1:rev:0000000000000000000000000000000000000003",
+            "swh:1:dir:0000000000000000000000000000000000000002",
         ),
     ]
-    assert set(actual) == set(expected)
+    # As there are four valid answers (up to reordering), we cannot check for
+    # equality. Instead, we check the client returned all edges but one.
+    assert set(actual).issubset(set(expected))
+    assert len(actual) == 3
 
 
 def test_visit_edges_diamond_pattern(graph_client):
@@ -235,9 +280,9 @@ def test_walk(graph_client):
 
 
 def test_random_walk(graph_client):
-    """as the walk is random, we test a visit from a cnt node to the only origin in
-    the dataset, and only check the final node of the path (i.e., the origin)
-
+    """as the walk is random, we test a visit from a cnt node to the only
+    origin in the dataset, and only check the final node of the path
+    (i.e., the origin)
     """
     args = ("swh:1:cnt:0000000000000000000000000000000000000001", "ori")
     kwargs = {"direction": "backward"}
@@ -279,17 +324,19 @@ def test_count(graph_client):
 
 
 def test_param_validation(graph_client):
-    with raises(RemoteException) as exc_info:  # SWHID not found
+    with raises(GraphArgumentException) as exc_info:  # SWHID not found
         list(graph_client.leaves("swh:1:ori:fff0000000000000000000000000000000000021"))
-    assert exc_info.value.response.status_code == 404
+    if exc_info.value.response:
+        assert exc_info.value.response.status_code == 404
 
-    with raises(RemoteException) as exc_info:  # malformed SWHID
+    with raises(GraphArgumentException) as exc_info:  # malformed SWHID
         list(
             graph_client.neighbors("swh:1:ori:fff000000zzzzzz0000000000000000000000021")
         )
-    assert exc_info.value.response.status_code == 400
+    if exc_info.value.response:
+        assert exc_info.value.response.status_code == 400
 
-    with raises(RemoteException) as exc_info:  # malformed edge specificaiton
+    with raises(GraphArgumentException) as exc_info:  # malformed edge specificaiton
         list(
             graph_client.visit_nodes(
                 "swh:1:dir:0000000000000000000000000000000000000016",
@@ -297,9 +344,10 @@ def test_param_validation(graph_client):
                 direction="backward",
             )
         )
-    assert exc_info.value.response.status_code == 400
+    if exc_info.value.response:
+        assert exc_info.value.response.status_code == 400
 
-    with raises(RemoteException) as exc_info:  # malformed direction
+    with raises(GraphArgumentException) as exc_info:  # malformed direction
         list(
             graph_client.visit_nodes(
                 "swh:1:dir:0000000000000000000000000000000000000016",
@@ -307,7 +355,8 @@ def test_param_validation(graph_client):
                 direction="notadirection",
             )
         )
-    assert exc_info.value.response.status_code == 400
+    if exc_info.value.response:
+        assert exc_info.value.response.status_code == 400
 
 
 @pytest.mark.skip(reason="currently disabled due to T1969")
