@@ -7,15 +7,13 @@
 
 """
 
+from datetime import datetime
+from enum import Enum
 import logging
 import os
-import subprocess
-
-from enum import Enum
-from datetime import datetime
 from pathlib import Path
+import subprocess
 from typing import Dict, List, Set
-from click import ParamType
 
 from swh.graph.config import check_config_compress
 
@@ -49,6 +47,7 @@ STEP_ARGV: Dict[CompressionStep, List[str]] = {
     CompressionStep.MPH: [
         "{java}",
         "it.unimi.dsi.sux4j.mph.GOVMinimalPerfectHashFunction",
+        "--byte-array",
         "--temp-dir",
         "{tmp_dir}",
         "{out_dir}/{graph_name}.mph",
@@ -60,8 +59,11 @@ STEP_ARGV: Dict[CompressionStep, List[str]] = {
         "zstdcat",
         "{in_dir}/{graph_name}.edges.csv.zst",
         "|",
+        "cut -d' ' -f1,2",
+        "|",
         "{java}",
         "it.unimi.dsi.big.webgraph.ScatteredArcsASCIIGraph",
+        "--byte-array",
         "--temp-dir",
         "{tmp_dir}",
         "--function",
@@ -121,7 +123,7 @@ STEP_ARGV: Dict[CompressionStep, List[str]] = {
         "{in_dir}/{graph_name}.nodes.csv.zst",
         "|",
         "{java}",
-        "org.softwareheritage.graph.backend.MapBuilder",
+        "org.softwareheritage.graph.maps.NodeMapBuilder",
         "{out_dir}/{graph_name}",
         "{tmp_dir}",
     ],
@@ -136,50 +138,6 @@ STEP_ARGV: Dict[CompressionStep, List[str]] = {
 }
 
 
-class StepOption(ParamType):
-    """click type for specifying a compression step on the CLI
-
-    parse either individual steps, specified as step names or integers, or step
-    ranges
-
-    """
-
-    name = "compression step"
-
-    def convert(self, value, param, ctx) -> Set[CompressionStep]:
-        steps: Set[CompressionStep] = set()
-
-        specs = value.split(",")
-        for spec in specs:
-            if "-" in spec:  # step range
-                (raw_l, raw_r) = spec.split("-", maxsplit=1)
-                if raw_l == "":  # no left endpoint
-                    raw_l = COMP_SEQ[0].name
-                if raw_r == "":  # no right endpoint
-                    raw_r = COMP_SEQ[-1].name
-                l_step = self.convert(raw_l, param, ctx)
-                r_step = self.convert(raw_r, param, ctx)
-                if len(l_step) != 1 or len(r_step) != 1:
-                    self.fail(f"invalid step specification: {value}, " f"see --help")
-                l_idx = l_step.pop()
-                r_idx = r_step.pop()
-                steps = steps.union(
-                    set(map(CompressionStep, range(l_idx.value, r_idx.value + 1)))
-                )
-            else:  # singleton step
-                try:
-                    steps.add(CompressionStep(int(spec)))  # integer step
-                except ValueError:
-                    try:
-                        steps.add(CompressionStep[spec.upper()])  # step name
-                    except KeyError:
-                        self.fail(
-                            f"invalid step specification: {value}, " f"see --help"
-                        )
-
-        return steps
-
-
 def do_step(step, conf):
     cmd = " ".join(STEP_ARGV[step]).format(**conf)
 
